import React, { isValidElement, useEffect } from 'react';
import { StyleSheet, View, Text, Image, TouchableWithoutFeedback, } from 'react-native';
import Badge from '../Badge';
const TabBarItem = props => {
    const { title, selected = false, badge, dot = false, icon, iconSize, activeColor, inactiveColor, selectedIcon, onPress = () => 1, } = props;
    const renderIcon = selected ? selectedIcon : icon;
    const currentColor = selected ? activeColor : inactiveColor;
    // 提前加载图片，防止切换时导致闪动
    useEffect(() => {
        [selectedIcon, icon].forEach(image => {
            if (!isValidElement(image) && typeof image === 'string') {
                Image.prefetch(image);
            }
        });
        return () => { };
    }, [selectedIcon, icon]);
    return (React.createElement(TouchableWithoutFeedback, { onPress: onPress },
        React.createElement(View, { style: styles.TabBarItem },
            React.createElement(View, { style: styles.wrap },
                isValidElement(renderIcon) ? (React.createElement(View, { style: { width: iconSize, height: iconSize } }, renderIcon)) : (React.createElement(Image, { source: renderIcon, style: { width: iconSize, height: iconSize } })),
                React.createElement(Text, { style: [styles.title, { color: currentColor }] }, title),
                badge && React.createElement(Badge, { corner: true, text: badge, size: "small", dot: dot })))));
};
const styles = StyleSheet.create({
    TabBarItem: {
        flex: 1,
        alignItems: 'center',
        justifyContent: 'center',
    },
    wrap: {
        position: 'relative',
        alignItems: 'center',
        justifyContent: 'center',
    },
    title: {
        fontSize: 13,
        marginTop: 4,
    },
});
export default TabBarItem;
